version=2.5.12

# check hostname if(conrad)
if [[ $HOSTNAME = SEM* ]] ; then
	echo
	echo Shutting down sampling services ...
	/home/hans/stop_services.sh >/dev/null 2>&1 || exit
	echo

	set -x

	# set update file variable; check for existence
	startdir=`pwd`
	tgz=$startdir/update/hans1.tgz
	test -f $tgz || exit
	test -d /home/hans1 || exit

	# delete previous backed up files
	cd /home || exit
	rm -rf /home/hans2

	# check for diskspace > 100mb
	avail=$(df --output=avail / | tail -1)
	test -n "$avail" || exit
	test $avail -ge 10000 || exit

	# clear tmp directory
	rm -rf /home/tmp
	mkdir /home/tmp || exit
	cd /home/tmp || exit


	# kill lighttpd-watchdog  
	# otherwise update process may fail due to killed lighttpd
	pkill -f watch_lighttpd.sh
	# lighttpd watchdog is changed in this update (2.5.11)

	# extract hans dir in tmp dir
	# move hans1 to hans2 and replace hans1 with new files
	tar xzf $tgz || exit
	cd ..
	mv hans1 hans2 || exit
	mv tmp/hans1 . || exit
	rmdir tmp || exit

	#copy old configuration files to new folder
	cd /home/hans1/www/w || exit
	rm *
	cd /home/hans2/www/w || exit
	cp *.cfg /home/hans1/www/w
	cd /home/hans1/www/w || exit
	chown http *
	cp /home/hans2/access_point/hostapd.conf /home/hans1/access_point


	# 1. php.ini update (enable zip.so)
	sed -i 's/;\(extension=zip.so\)/\1/' /etc/php/php.ini
	# restart lighttpd or device afterwards

	# 2. psql config
	sed -i 's/\(track_counts =\) off/\1 on/' /data/postgres/data/postgresql.conf
	sed -i 's/^#\(autovacuum_vacuum_scale_factor =\) [[:digit:]].[[:digit:]][[:digit:]]\{0,1\}/\1 0.01/' /data/postgres/data/postgresql.conf

	# 3. mail permissions
	chmod 666 /etc/ssmtp/ssmtp.conf || exit
	
	# 4. update UI	
	# stop running php scripts/watchdog
	pkill -f watchdog-qi.sh
	killall php
		
	# extract and update new UI
	mkdir -p /data/update/
	tar -xpzf $startdir/update/eds.tgz -C /data/update/ || exit
	rm -rf /data/qi/www/eds/
	mv /data/update/* /data/qi/www/
	rm -rf /data/update/
	
	# move UI archive 
	mv $startdir/update/eds.tgz /data/hans/eds.tgz
	
	# 5. update lighttpd conf
	# overwrite conf (includes basic auth for /admin)
	mv $startdir/update/lighttpd.conf /etc/lighttpd/

	# 6. install wpa_actiond
	# establishing wlan connections is changed in this update
	yes | pacman -U $startdir/update/wpa_actiond-1.4-2-armv7h.pkg.tar.xz

	# 7. increase /var/tmp size in /etc/fstab
	sed -i 's!\(none /var/tmp tmpfs size=\)15M!\130M!' /etc/fstab

	#update version number/
	{
		tail -1000 /home/hans2/version.txt
		echo
		date '+%Y-%m-%d %T'
		echo Firmware Version $version
	} > /home/hans1/version.txt
	
	sync

	> $startdir/install-ok || exit
	> $startdir/reboot || exit

	echo
	echo Installation succeeded.

	set +x

else
	#echo "url=http://update.ruppenergy.com/eds-update/industry" > update_cfg_file	
	echo "change update url for industry version"
fi
